@@ -7,7 +7,7 @@ ConntrackProducer::ConntrackProducer(ostream &stdMsg, Storage &storage)
     d_storage(storage)
 {
     if (access(d_options.conntrackDevice(), R_OK) != 0)
-        throw Exception() << "Cannot read " << d_options.conntrackDevice();
+        throw Exception{} << "Cannot read " << d_options.conntrackDevice();
 
     Signal::instance().add(SIGHUP, *this);      // ignored
     Signal::instance().add(SIGINT, *this);
