@@ -9,7 +9,7 @@
 void ConntrackProducer::run()
 {
     size_t max = d_options.conntrackRestart();
-    d_stdMsg << "starting `" << d_options.conntrackCommand() << 
+    d_stdMsg << "Starting `" << d_options.conntrackCommand() << 
                 "' (max " << max << " restarts)" << endl;
 
     ++max;      // restarts, so add 1 for initial startup.
