@@ -5,11 +5,11 @@ ConntrackRecord::ConntrackRecord(Protocol type, Pattern const &pattern)
     d_pattern(pattern)
 {
     setLastUsed(::time(0));
-
+    
     setType(pat(CTicmp::TYPE) == "NEW" ? NEW : DESTROY);
 
-    setTime(stoul(pat(CTicmp::SECONDS)), 
-            stoul(pat(CTicmp::MU_SECONDS)));
+    setAllTimes(stoul(pat(CTicmp::SECONDS)), 
+                stoul(pat(CTicmp::MU_SECONDS)));
 
     if (type == ICMP)
         initICMP(pattern);
