@@ -34,7 +34,12 @@ struct IPbase
     
         static LogType  s_logType;
         static std::pair<char const *, char const *> s_logTypeText[];
-    
+
+    protected:    
+        void (IPbase::*d_via)(Record const &) const;        // via or noVia
+        void (IPbase::*d_byteCounts)(Record const &) const; // byteCounts or
+                                                            // noByteCounts
+
     public:
         virtual ~IPbase();
 
@@ -83,6 +88,9 @@ struct IPbase
         void maybeSizeLog(size_t *lastSize, size_t keyMapSize, 
                           char const *label);
 
+        void via(Record const &record) const;
+        void byteCounts(Record const &record) const;
+
     private:
         virtual void cleanupHook();        
 
@@ -96,6 +104,12 @@ struct IPbase
 
         virtual void outDev(RecordPtr &next) = 0; 
 
+        virtual void vVia(Record const &record) const;
+        virtual void vByteCounts(Record const &record) const;
+
+        void noVia(Record const &record) const;
+        void noByteCounts(Record const &record) const;
+
         void destroy(Record const &record);  
         void logData(Record const &record) const;
         void noDataLog(Record const &record) const;
