@@ -4,7 +4,7 @@
 #include <fstream>
 
 #include <bobcat/fork>
-#include <bobcat/multistreambuf>
+#include <bobcat/multibuf>
 
 #include "../options/options.h"
 #include "../rotatingstream/rotatingstream.h"
@@ -24,7 +24,7 @@ class NatFork: public FBB::Fork
     std::unique_ptr<FBB::SyslogStream> d_syslog;
     RotatingStream d_log;
 
-    FBB::MultiStreambuf d_multiStreambuf;
+    FBB::MultiBuf d_multiStreambuf;
     std::ostream d_stdMsg;
 
     Options::Mode d_mode;
