@@ -49,7 +49,9 @@ struct Options: public IP_Types
         bool d_stdout;
         bool d_terminate;
         bool d_debug;
-
+        bool d_showVia;
+        bool d_showBytes;
+        
         Mode d_mode;
 
         size_t d_IPheaderSize = 0;
@@ -120,6 +122,8 @@ struct Options: public IP_Types
         bool stdout() const;
         bool kill() const;
         bool debug() const;
+        bool showVia() const;
+        bool showBytes() const;
 
         size_t IPheaderSize() const;
         size_t verbose() const;
@@ -168,8 +172,8 @@ struct Options: public IP_Types
         static std::string const &protocolName(Protocol protocol);
         static char const *defaultConfigPath();
         static char const *defaultConntrackCommand();
-        static char const *defaultConntrackDevice();
         static char const *defaultConntrackArgs();
+        static char const *defaultConntrackDevice();
         static char const *defaultSyslogIdent();
         static char const *defaultSyslogFacility();
         static char const *defaultSyslogPriority();
@@ -210,6 +214,16 @@ inline bool Options::debug() const
     return d_debug;
 }
 
+inline bool Options::showVia() const
+{   
+    return d_showVia;
+}
+
+inline bool Options::showBytes() const
+{   
+    return d_showBytes;
+}
+
 inline size_t Options::verbose() const
 {   
     return d_verbose;
@@ -370,6 +384,11 @@ inline std::string const &Options::basename() const
     return d_arg.basename();
 }
 
+inline char const *Options::defaultConntrackArgs()
+{
+    return s_defaultConntrackArgs;
+}
+
 inline char const *Options::defaultConntrackCommand() 
 {
     return s_defaultConntrackCommand;
