@@ -5,7 +5,8 @@
 
 Options::Options()
 :
-    d_arg(ArgConfig::instance())
+    d_arg(ArgConfig::instance()),
+    d_showVia(d_arg.option(0, "no-via") == 0)
 {
     d_terminate = d_arg.option(0, "terminate");
 
