@@ -5,8 +5,10 @@ void Options::setConntrack()
     if (not d_arg.option(&d_conntrackDevice, "conntrack-device"))
         d_conntrackDevice = s_defaultConntrackDevice;
 
+
     if (not d_arg.option(&d_conntrackCommand, "conntrack-command"))
-        d_conntrackCommand = s_defaultConntrackCommand;
+        (d_conntrackCommand = s_defaultConntrackCommand) += 
+                                                 s_defaultConntrackArgs; 
 
     d_conntrackCommand +=
             (
@@ -15,8 +17,7 @@ void Options::setConntrack()
                         s_protocol2name.find(*d_protocols.begin())->second
                 :
                     ""s
-            )
-        + s_defaultConntrackArgs;
+            );
 
     string value;
     if (d_arg.option(&value, "conntrack-restart"))
