@@ -2,7 +2,8 @@
 
 void Record::addSentBytes(Record const &next)
 {
-    d_sentBytes += next.payload();
+    // d_sentBytes += next.payload();
+    d_sentBytes += next.d_sentBytes;
 
     setEndTime(next);
 }
