@@ -1,6 +1,6 @@
 #include "showseconds.ih"
 
-void (*ShowSeconds::s_show)(std::ostream &out, std::string const &time) =
+void (*ShowSeconds::s_show)(std::ostream &out, size_t time) =
         ShowSeconds::rawTime;
 
 string ShowSeconds::s_utcMarker;
